# GCGC

> GCGC is a python package for feature processing on Biological Sequences.

[![](https://img.shields.io/pypi/v/gcgc.svg)](https://pypi.python.org/pypi/gcgc)
[![](https://img.shields.io/travis/tshauck/gcgc.svg)](https://travis-ci.org/tshauck/gcgc)

## Installation

Install GCGC via pip:

```sh
$ pip install gcgc
```

If you'd like to use one of the third party tools, install the related "extras".

```bash
$ pip install gcgc -E torch
```

## Documentation

The GCGC documentation is at [gcgc.trenthauck.com](http://gcgc.trenthauck.com).

## Development Board

The GCGC development board is hosted on [notion](https://www.notion.so/3649815c53324f01ae03abc99707dc68?v=98d8b29c39544dca9cde8ddc0dd8c98b).
